# -*- coding=utf8 -*-
#******************************************************************************
# addon.py
#------------------------------------------------------------------------------
#
# Copyright (c) 2015 LivingOn <LivingOn@xmail.net>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#******************************************************************************
import os
import xbmc
import xbmcgui
import xbmcaddon

from resources.lib.MediaTypes import MediaType
from resources.lib.ConvertPlaylist import convert

class Youtube2Kodi(object):
    NAME = "Youtube2Kodi"
    PLUGINNAME = "script.youtube2kodi"

    class UpdateMonitor(xbmc.Monitor):
        def __init__(self, yt2series):
            super(xbmc.Monitor, self).__init__()
            self._yt2series = yt2series
        
        def onScanFinished(self, database="video"):
            self._yt2series._library_update_finished()

        onDatabaseUpdated = onScanFinished
    
    def __init__(self):
        self._initialize_attributes()
        if self._series_library or self._movies_library:
            self._menue()
        else:    
            self._settings()
    
    def _initialize_attributes(self):
        self._addon = xbmcaddon.Addon(self.PLUGINNAME)
        self._run = True
        self._library_update_is_active = False
        self._load_settings()
        self._dialog = xbmcgui.Dialog()
        self._monitor = self.UpdateMonitor(self)
    
    def _load_settings(self):
        self._importpath = self._addon.getSetting("importpath")
        self._series_library = self._addon.getSetting("serieslibrary")
        self._movies_library = self._addon.getSetting("movieslibrary")
    
    def _menue(self):
        menue = [
            (self._addon.getLocalizedString(30500), self._import), 
            (self._addon.getLocalizedString(30520), self._settings),
            (self._addon.getLocalizedString(30530), self._stop_run)
        ]
        series = self._series_library
        movies = self._movies_library
        if MediaType.exists_inactive_streams(series, movies):
            title = self._addon.getLocalizedString(30510)
            menue.insert(1, (title, self._activate_all_streams))
        nr = self._dialog.select(self.NAME, [title for title,_ in menue])
        if menue[nr][1]:
            menue[nr][1]()
        while self._run:
            xbmc.sleep(1000)

    def _playlist_selection(self, path):
        title = "%s - %s" % (self.NAME, self._addon.getLocalizedString(30540))
        return self._dialog.browse(1, title, "files", '', False, False, path)

    def _import(self):
        playlist = self._playlist_selection(self._importpath)
        if os.path.isfile(playlist):
            convert(self._movies_library, self._series_library, playlist)
            for serie in MediaType.all_strm_folder():
                self._update_library(serie)
            MediaType.clear_all_strm_folder()
        self._menue()
                            
    def _settings(self):
        self._addon.openSettings()
        self._load_settings()
        self._menue()

    def _stop_run(self):
        self._run = False

    def _activate_all_streams(self):
        msg = self._addon.getLocalizedString(30550) 
        if self._dialog.yesno(self.NAME, msg):
            self._dialog.notification(
                self.NAME, 
                self._addon.getLocalizedString(30560),
                xbmcgui.NOTIFICATION_INFO, 3000
            )
            MediaType.activate_all_streams(
                self._series_library, 
                self._movies_library
            )
        self._menue()

    def _update_library(self, path):
        self._library_update_activated()
        xbmc.executebuiltin('RunScript(%s, %s)' % (self._updatescript(), path))
        print("###", path)
        while self._library_update_is_active:
            xbmc.sleep(1000)
        
    def _library_update_activated(self):
        self._library_update_is_active = True
        
    def _library_update_finished(self):
        self._library_update_is_active = False

    @classmethod
    def _updatescript(cls):
        return "%saddons/%s/resources/scripts/UpdateLibrary.py" % (
            xbmc.translatePath("special://home"),
            cls.PLUGINNAME
        )
    

if __name__ == "__main__":
    Youtube2Kodi()
